==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/EXTMENU_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EXTMENU_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EXTMENU_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUPARENT"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIDEMENU" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILEICON" minOccurs="0"/>
 *         &lt;element name="UPDATECOUNT" type="{http://www.w3.org/2001/XMLSchema}long"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EXTMENU_Type", propOrder = {
    "extmenucode",
    "extmenuparent",
    "extmenutype",
    "sequencenumber",
    "hidemenu",
    "mobile",
    "mobileicon",
    "updatecount"
})
@XmlSeeAlso({
    FUNCTION_Type.class,
    FOLDER_Type.class,
    MENU_Type.class
})
public class EXTMENU_Type {

    @XmlElement(name = "EXTMENUCODE", required = true)
    protected String extmenucode;
    @XmlElement(name = "EXTMENUPARENT", required = true)
    protected String extmenuparent;
    @XmlElement(name = "EXTMENUTYPE", required = true)
    protected String extmenutype;
    @XmlElement(name = "SEQUENCENUMBER")
    protected long sequencenumber;
    @XmlElement(name = "HIDEMENU")
    protected String hidemenu;
    @XmlElement(name = "MOBILE")
    protected String mobile;
    @XmlElement(name = "MOBILEICON")
    protected String mobileicon;
    @XmlElement(name = "UPDATECOUNT")
    protected long updatecount;

    /**
     * Gets the value of the extmenucode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUCODE() {
        return extmenucode;
    }

    /**
     * Sets the value of the extmenucode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUCODE(String value) {
        this.extmenucode = value;
    }

    /**
     * Gets the value of the extmenuparent property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUPARENT() {
        return extmenuparent;
    }

    /**
     * Sets the value of the extmenuparent property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUPARENT(String value) {
        this.extmenuparent = value;
    }

    /**
     * Gets the value of the extmenutype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUTYPE() {
        return extmenutype;
    }

    /**
     * Sets the value of the extmenutype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUTYPE(String value) {
        this.extmenutype = value;
    }

    /**
     * Gets the value of the sequencenumber property.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Sets the value of the sequencenumber property.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

    /**
     * Gets the value of the hidemenu property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHIDEMENU() {
        return hidemenu;
    }

    /**
     * Sets the value of the hidemenu property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHIDEMENU(String value) {
        this.hidemenu = value;
    }

    /**
     * Gets the value of the mobile property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILE() {
        return mobile;
    }

    /**
     * Sets the value of the mobile property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILE(String value) {
        this.mobile = value;
    }

    /**
     * Gets the value of the mobileicon property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEICON() {
        return mobileicon;
    }

    /**
     * Sets the value of the mobileicon property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEICON(String value) {
        this.mobileicon = value;
    }

    /**
     * Gets the value of the updatecount property.
     * 
     */
    public long getUPDATECOUNT() {
        return updatecount;
    }

    /**
     * Sets the value of the updatecount property.
     * 
     */
    public void setUPDATECOUNT(long value) {
        this.updatecount = value;
    }

}

==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_fields/EXTMENU_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EXTMENU_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EXTMENU_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUPARENT"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIDEMENU" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILEICON" minOccurs="0"/>
 *         &lt;element name="UPDATECOUNT" type="{http://www.w3.org/2001/XMLSchema}long"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EXTMENU_Type", propOrder = {
    "extmenucode",
    "extmenuparent",
    "extmenutype",
    "sequencenumber",
    "hidemenu",
    "mobile",
    "mobileicon",
    "updatecount"
})
@XmlSeeAlso({
    FUNCTION_Type.class,
    FOLDER_Type.class,
    MENU_Type.class
})
public class EXTMENU_Type {

    @XmlElement(name = "EXTMENUCODE", required = true)
    protected String extmenucode;
    @XmlElement(name = "EXTMENUPARENT", required = true)
    protected String extmenuparent;
    @XmlElement(name = "EXTMENUTYPE", required = true)
    protected String extmenutype;
    @XmlElement(name = "SEQUENCENUMBER")
    protected long sequencenumber;
    @XmlElement(name = "HIDEMENU")
    protected String hidemenu;
    @XmlElement(name = "MOBILE")
    protected String mobile;
    @XmlElement(name = "MOBILEICON")
    protected String mobileicon;
    @XmlElement(name = "UPDATECOUNT")
    protected long updatecount;

    /**
     * Obtient la valeur de la propriété extmenucode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUCODE() {
        return extmenucode;
    }

    /**
     * Définit la valeur de la propriété extmenucode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUCODE(String value) {
        this.extmenucode = value;
    }

    /**
     * Obtient la valeur de la propriété extmenuparent.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUPARENT() {
        return extmenuparent;
    }

    /**
     * Définit la valeur de la propriété extmenuparent.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUPARENT(String value) {
        this.extmenuparent = value;
    }

    /**
     * Obtient la valeur de la propriété extmenutype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUTYPE() {
        return extmenutype;
    }

    /**
     * Définit la valeur de la propriété extmenutype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUTYPE(String value) {
        this.extmenutype = value;
    }

    /**
     * Obtient la valeur de la propriété sequencenumber.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Définit la valeur de la propriété sequencenumber.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

    /**
     * Obtient la valeur de la propriété hidemenu.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHIDEMENU() {
        return hidemenu;
    }

    /**
     * Définit la valeur de la propriété hidemenu.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHIDEMENU(String value) {
        this.hidemenu = value;
    }

    /**
     * Obtient la valeur de la propriété mobile.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILE() {
        return mobile;
    }

    /**
     * Définit la valeur de la propriété mobile.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILE(String value) {
        this.mobile = value;
    }

    /**
     * Obtient la valeur de la propriété mobileicon.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEICON() {
        return mobileicon;
    }

    /**
     * Définit la valeur de la propriété mobileicon.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEICON(String value) {
        this.mobileicon = value;
    }

    /**
     * Obtient la valeur de la propriété updatecount.
     * 
     */
    public long getUPDATECOUNT() {
        return updatecount;
    }

    /**
     * Définit la valeur de la propriété updatecount.
     * 
     */
    public void setUPDATECOUNT(long value) {
        this.updatecount = value;
    }

}
